OC.L10N.register(
    "templateeditor",
    {
    "Could not load template" : "Klarte ikke å laste mal",
    "Saved" : "Lagret",
    "Reset" : "Tilbakestill",
    "An error occurred" : "En feil har oppstått",
    "Sharing email - public link shares (HTML)" : "Delings-epost - offentlige lenke-delinger (HTML)",
    "Sharing email - public link shares (plain text fallback)" : "Delings-epost - offentlige lenke-delinger (ren tekst)",
    "Sharing email (HTML)" : "Delings-epost (HTML)",
    "Sharing email (plain text fallback)" : "Delings-epost (ren tekst)",
    "Lost password mail" : "E-post om mistet passord",
    "New user email (HTML)" : "E-post om ny bruker (HTML)",
    "New user email (plain text fallback)" : "E-post om ny bruker (ren tekst)",
    "Activity notification mail" : "E-post med varsling om aktivitet",
    "Mail Templates" : "Maler for e-poster",
    "Theme" : "Drakt",
    "Template" : "Mal",
    "Please choose a template" : "Velg en mal",
    "Save" : "Lagre"
},
"nplurals=2; plural=(n != 1);");
